@@ -143,81 +143,88 @@ __all__ = (
 AntipatternSeveritySummaryTypeDef = TypedDict(
     "AntipatternSeveritySummaryTypeDef",
     {
-        "count": NotRequired[int],
-        "severity": NotRequired[SeverityType],
+        "count": int,
+        "severity": SeverityType,
     },
+    total=False,
 )
 
 ApplicationComponentDetailTypeDef = TypedDict(
     "ApplicationComponentDetailTypeDef",
     {
-        "analysisStatus": NotRequired[SrcCodeOrDbAnalysisStatusType],
-        "antipatternReportS3Object": NotRequired["S3ObjectTypeDef"],
-        "antipatternReportStatus": NotRequired[AntipatternReportStatusType],
-        "antipatternReportStatusMessage": NotRequired[str],
-        "appType": NotRequired[AppTypeType],
-        "associatedServerId": NotRequired[str],
-        "databaseConfigDetail": NotRequired["DatabaseConfigDetailTypeDef"],
-        "id": NotRequired[str],
-        "inclusionStatus": NotRequired[InclusionStatusType],
-        "lastAnalyzedTimestamp": NotRequired[datetime],
-        "listAntipatternSeveritySummary": NotRequired[List["AntipatternSeveritySummaryTypeDef"]],
-        "moreServerAssociationExists": NotRequired[bool],
-        "name": NotRequired[str],
-        "osDriver": NotRequired[str],
-        "osVersion": NotRequired[str],
-        "recommendationSet": NotRequired["RecommendationSetTypeDef"],
-        "resourceSubType": NotRequired[ResourceSubTypeType],
-        "sourceCodeRepositories": NotRequired[List["SourceCodeRepositoryTypeDef"]],
-        "statusMessage": NotRequired[str],
+        "analysisStatus": SrcCodeOrDbAnalysisStatusType,
+        "antipatternReportS3Object": "S3ObjectTypeDef",
+        "antipatternReportStatus": AntipatternReportStatusType,
+        "antipatternReportStatusMessage": str,
+        "appType": AppTypeType,
+        "associatedServerId": str,
+        "databaseConfigDetail": "DatabaseConfigDetailTypeDef",
+        "id": str,
+        "inclusionStatus": InclusionStatusType,
+        "lastAnalyzedTimestamp": datetime,
+        "listAntipatternSeveritySummary": List["AntipatternSeveritySummaryTypeDef"],
+        "moreServerAssociationExists": bool,
+        "name": str,
+        "osDriver": str,
+        "osVersion": str,
+        "recommendationSet": "RecommendationSetTypeDef",
+        "resourceSubType": ResourceSubTypeType,
+        "sourceCodeRepositories": List["SourceCodeRepositoryTypeDef"],
+        "statusMessage": str,
     },
+    total=False,
 )
 
 ApplicationComponentStrategyTypeDef = TypedDict(
     "ApplicationComponentStrategyTypeDef",
     {
-        "isPreferred": NotRequired[bool],
-        "recommendation": NotRequired["RecommendationSetTypeDef"],
-        "status": NotRequired[StrategyRecommendationType],
+        "isPreferred": bool,
+        "recommendation": "RecommendationSetTypeDef",
+        "status": StrategyRecommendationType,
     },
+    total=False,
 )
 
 ApplicationComponentSummaryTypeDef = TypedDict(
     "ApplicationComponentSummaryTypeDef",
     {
-        "appType": NotRequired[AppTypeType],
-        "count": NotRequired[int],
+        "appType": AppTypeType,
+        "count": int,
     },
+    total=False,
 )
 
 ApplicationPreferencesTypeDef = TypedDict(
     "ApplicationPreferencesTypeDef",
     {
-        "managementPreference": NotRequired["ManagementPreferenceTypeDef"],
+        "managementPreference": "ManagementPreferenceTypeDef",
     },
+    total=False,
 )
 
 AssessmentSummaryTypeDef = TypedDict(
     "AssessmentSummaryTypeDef",
     {
-        "antipatternReportS3Object": NotRequired["S3ObjectTypeDef"],
-        "antipatternReportStatus": NotRequired[AntipatternReportStatusType],
-        "antipatternReportStatusMessage": NotRequired[str],
-        "lastAnalyzedTimestamp": NotRequired[datetime],
-        "listAntipatternSeveritySummary": NotRequired[List["AntipatternSeveritySummaryTypeDef"]],
-        "listApplicationComponentStrategySummary": NotRequired[List["StrategySummaryTypeDef"]],
-        "listApplicationComponentSummary": NotRequired[List["ApplicationComponentSummaryTypeDef"]],
-        "listServerStrategySummary": NotRequired[List["StrategySummaryTypeDef"]],
-        "listServerSummary": NotRequired[List["ServerSummaryTypeDef"]],
+        "antipatternReportS3Object": "S3ObjectTypeDef",
+        "antipatternReportStatus": AntipatternReportStatusType,
+        "antipatternReportStatusMessage": str,
+        "lastAnalyzedTimestamp": datetime,
+        "listAntipatternSeveritySummary": List["AntipatternSeveritySummaryTypeDef"],
+        "listApplicationComponentStrategySummary": List["StrategySummaryTypeDef"],
+        "listApplicationComponentSummary": List["ApplicationComponentSummaryTypeDef"],
+        "listServerStrategySummary": List["StrategySummaryTypeDef"],
+        "listServerSummary": List["ServerSummaryTypeDef"],
     },
+    total=False,
 )
 
 AssociatedApplicationTypeDef = TypedDict(
     "AssociatedApplicationTypeDef",
     {
-        "id": NotRequired[str],
-        "name": NotRequired[str],
+        "id": str,
+        "name": str,
     },
+    total=False,
 )
 
 AwsManagedResourcesTypeDef = TypedDict(
@@ -230,61 +237,67 @@ AwsManagedResourcesTypeDef = TypedDict(
 BusinessGoalsTypeDef = TypedDict(
     "BusinessGoalsTypeDef",
     {
-        "licenseCostReduction": NotRequired[int],
-        "modernizeInfrastructureWithCloudNativeTechnologies": NotRequired[int],
-        "reduceOperationalOverheadWithManagedServices": NotRequired[int],
-        "speedOfMigration": NotRequired[int],
+        "licenseCostReduction": int,
+        "modernizeInfrastructureWithCloudNativeTechnologies": int,
+        "reduceOperationalOverheadWithManagedServices": int,
+        "speedOfMigration": int,
     },
+    total=False,
 )
 
 CollectorTypeDef = TypedDict(
     "CollectorTypeDef",
     {
-        "collectorHealth": NotRequired[CollectorHealthType],
-        "collectorId": NotRequired[str],
-        "collectorVersion": NotRequired[str],
-        "hostName": NotRequired[str],
-        "ipAddress": NotRequired[str],
-        "lastActivityTimeStamp": NotRequired[str],
-        "registeredTimeStamp": NotRequired[str],
+        "collectorHealth": CollectorHealthType,
+        "collectorId": str,
+        "collectorVersion": str,
+        "hostName": str,
+        "ipAddress": str,
+        "lastActivityTimeStamp": str,
+        "registeredTimeStamp": str,
     },
+    total=False,
 )
 
 DataCollectionDetailsTypeDef = TypedDict(
     "DataCollectionDetailsTypeDef",
     {
-        "completionTime": NotRequired[datetime],
-        "failed": NotRequired[int],
-        "inProgress": NotRequired[int],
-        "servers": NotRequired[int],
-        "startTime": NotRequired[datetime],
-        "status": NotRequired[AssessmentStatusType],
-        "success": NotRequired[int],
+        "completionTime": datetime,
+        "failed": int,
+        "inProgress": int,
+        "servers": int,
+        "startTime": datetime,
+        "status": AssessmentStatusType,
+        "success": int,
     },
+    total=False,
 )
 
 DatabaseConfigDetailTypeDef = TypedDict(
     "DatabaseConfigDetailTypeDef",
     {
-        "secretName": NotRequired[str],
+        "secretName": str,
     },
+    total=False,
 )
 
 DatabaseMigrationPreferenceTypeDef = TypedDict(
     "DatabaseMigrationPreferenceTypeDef",
     {
-        "heterogeneous": NotRequired["HeterogeneousTypeDef"],
-        "homogeneous": NotRequired["HomogeneousTypeDef"],
-        "noPreference": NotRequired["NoDatabaseMigrationPreferenceTypeDef"],
+        "heterogeneous": "HeterogeneousTypeDef",
+        "homogeneous": "HomogeneousTypeDef",
+        "noPreference": "NoDatabaseMigrationPreferenceTypeDef",
     },
+    total=False,
 )
 
 DatabasePreferencesTypeDef = TypedDict(
     "DatabasePreferencesTypeDef",
     {
-        "databaseManagementPreference": NotRequired[DatabaseManagementPreferenceType],
-        "databaseMigrationPreference": NotRequired["DatabaseMigrationPreferenceTypeDef"],
+        "databaseManagementPreference": DatabaseManagementPreferenceType,
+        "databaseMigrationPreference": "DatabaseMigrationPreferenceTypeDef",
     },
+    total=False,
 )
 
 GetApplicationComponentDetailsRequestRequestTypeDef = TypedDict(
@@ -395,22 +408,49 @@ GetRecommendationReportDetailsResponseTypeDef = TypedDict(
     },
 )
 
-GetServerDetailsRequestGetServerDetailsPaginateTypeDef = TypedDict(
-    "GetServerDetailsRequestGetServerDetailsPaginateTypeDef",
+_RequiredGetServerDetailsRequestGetServerDetailsPaginateTypeDef = TypedDict(
+    "_RequiredGetServerDetailsRequestGetServerDetailsPaginateTypeDef",
     {
         "serverId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalGetServerDetailsRequestGetServerDetailsPaginateTypeDef = TypedDict(
+    "_OptionalGetServerDetailsRequestGetServerDetailsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-GetServerDetailsRequestRequestTypeDef = TypedDict(
-    "GetServerDetailsRequestRequestTypeDef",
+
+class GetServerDetailsRequestGetServerDetailsPaginateTypeDef(
+    _RequiredGetServerDetailsRequestGetServerDetailsPaginateTypeDef,
+    _OptionalGetServerDetailsRequestGetServerDetailsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredGetServerDetailsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetServerDetailsRequestRequestTypeDef",
     {
         "serverId": str,
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalGetServerDetailsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetServerDetailsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class GetServerDetailsRequestRequestTypeDef(
+    _RequiredGetServerDetailsRequestRequestTypeDef, _OptionalGetServerDetailsRequestRequestTypeDef
+):
+    pass
+
 
 GetServerDetailsResponseTypeDef = TypedDict(
     "GetServerDetailsResponseTypeDef",
@@ -440,9 +480,10 @@ GetServerStrategiesResponseTypeDef = TypedDict(
 GroupTypeDef = TypedDict(
     "GroupTypeDef",
     {
-        "name": NotRequired[Literal["ExternalId"]],
-        "value": NotRequired[str],
+        "name": Literal["ExternalId"],
+        "value": str,
     },
+    total=False,
 )
 
 HeterogeneousTypeDef = TypedDict(
@@ -455,48 +496,52 @@ HeterogeneousTypeDef = TypedDict(
 HomogeneousTypeDef = TypedDict(
     "HomogeneousTypeDef",
     {
-        "targetDatabaseEngine": NotRequired[List[Literal["None specified"]]],
+        "targetDatabaseEngine": List[Literal["None specified"]],
     },
+    total=False,
 )
 
 ImportFileTaskInformationTypeDef = TypedDict(
     "ImportFileTaskInformationTypeDef",
     {
-        "completionTime": NotRequired[datetime],
-        "id": NotRequired[str],
-        "importName": NotRequired[str],
-        "inputS3Bucket": NotRequired[str],
-        "inputS3Key": NotRequired[str],
-        "numberOfRecordsFailed": NotRequired[int],
-        "numberOfRecordsSuccess": NotRequired[int],
-        "startTime": NotRequired[datetime],
-        "status": NotRequired[ImportFileTaskStatusType],
-        "statusReportS3Bucket": NotRequired[str],
-        "statusReportS3Key": NotRequired[str],
+        "completionTime": datetime,
+        "id": str,
+        "importName": str,
+        "inputS3Bucket": str,
+        "inputS3Key": str,
+        "numberOfRecordsFailed": int,
+        "numberOfRecordsSuccess": int,
+        "startTime": datetime,
+        "status": ImportFileTaskStatusType,
+        "statusReportS3Bucket": str,
+        "statusReportS3Key": str,
     },
+    total=False,
 )
 
 ListApplicationComponentsRequestListApplicationComponentsPaginateTypeDef = TypedDict(
     "ListApplicationComponentsRequestListApplicationComponentsPaginateTypeDef",
     {
-        "applicationComponentCriteria": NotRequired[ApplicationComponentCriteriaType],
-        "filterValue": NotRequired[str],
-        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
-        "sort": NotRequired[SortOrderType],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "applicationComponentCriteria": ApplicationComponentCriteriaType,
+        "filterValue": str,
+        "groupIdFilter": Sequence["GroupTypeDef"],
+        "sort": SortOrderType,
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListApplicationComponentsRequestRequestTypeDef = TypedDict(
     "ListApplicationComponentsRequestRequestTypeDef",
     {
-        "applicationComponentCriteria": NotRequired[ApplicationComponentCriteriaType],
-        "filterValue": NotRequired[str],
-        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
-        "sort": NotRequired[SortOrderType],
+        "applicationComponentCriteria": ApplicationComponentCriteriaType,
+        "filterValue": str,
+        "groupIdFilter": Sequence["GroupTypeDef"],
+        "maxResults": int,
+        "nextToken": str,
+        "sort": SortOrderType,
     },
+    total=False,
 )
 
 ListApplicationComponentsResponseTypeDef = TypedDict(
@@ -511,16 +556,18 @@ ListApplicationComponentsResponseTypeDef = TypedDict(
 ListCollectorsRequestListCollectorsPaginateTypeDef = TypedDict(
     "ListCollectorsRequestListCollectorsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListCollectorsRequestRequestTypeDef = TypedDict(
     "ListCollectorsRequestRequestTypeDef",
     {
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListCollectorsResponseTypeDef = TypedDict(
@@ -535,16 +582,18 @@ ListCollectorsResponseTypeDef = TypedDict(
 ListImportFileTaskRequestListImportFileTaskPaginateTypeDef = TypedDict(
     "ListImportFileTaskRequestListImportFileTaskPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListImportFileTaskRequestRequestTypeDef = TypedDict(
     "ListImportFileTaskRequestRequestTypeDef",
     {
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListImportFileTaskResponseTypeDef = TypedDict(
@@ -559,24 +608,26 @@ ListImportFileTaskResponseTypeDef = TypedDict(
 ListServersRequestListServersPaginateTypeDef = TypedDict(
     "ListServersRequestListServersPaginateTypeDef",
     {
-        "filterValue": NotRequired[str],
-        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
-        "serverCriteria": NotRequired[ServerCriteriaType],
-        "sort": NotRequired[SortOrderType],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "filterValue": str,
+        "groupIdFilter": Sequence["GroupTypeDef"],
+        "serverCriteria": ServerCriteriaType,
+        "sort": SortOrderType,
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListServersRequestRequestTypeDef = TypedDict(
     "ListServersRequestRequestTypeDef",
     {
-        "filterValue": NotRequired[str],
-        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
-        "serverCriteria": NotRequired[ServerCriteriaType],
-        "sort": NotRequired[SortOrderType],
+        "filterValue": str,
+        "groupIdFilter": Sequence["GroupTypeDef"],
+        "maxResults": int,
+        "nextToken": str,
+        "serverCriteria": ServerCriteriaType,
+        "sort": SortOrderType,
     },
+    total=False,
 )
 
 ListServersResponseTypeDef = TypedDict(
@@ -591,10 +642,11 @@ ListServersResponseTypeDef = TypedDict(
 ManagementPreferenceTypeDef = TypedDict(
     "ManagementPreferenceTypeDef",
     {
-        "awsManagedResources": NotRequired["AwsManagedResourcesTypeDef"],
-        "noPreference": NotRequired["NoManagementPreferenceTypeDef"],
-        "selfManageResources": NotRequired["SelfManageResourcesTypeDef"],
+        "awsManagedResources": "AwsManagedResourcesTypeDef",
+        "noPreference": "NoManagementPreferenceTypeDef",
+        "selfManageResources": "SelfManageResourcesTypeDef",
     },
+    total=False,
 )
 
 NetworkInfoTypeDef = TypedDict(
@@ -624,55 +676,61 @@ NoManagementPreferenceTypeDef = TypedDict(
 OSInfoTypeDef = TypedDict(
     "OSInfoTypeDef",
     {
-        "type": NotRequired[OSTypeType],
-        "version": NotRequired[str],
+        "type": OSTypeType,
+        "version": str,
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PrioritizeBusinessGoalsTypeDef = TypedDict(
     "PrioritizeBusinessGoalsTypeDef",
     {
-        "businessGoals": NotRequired["BusinessGoalsTypeDef"],
+        "businessGoals": "BusinessGoalsTypeDef",
     },
+    total=False,
 )
 
 PutPortfolioPreferencesRequestRequestTypeDef = TypedDict(
     "PutPortfolioPreferencesRequestRequestTypeDef",
     {
-        "applicationPreferences": NotRequired["ApplicationPreferencesTypeDef"],
-        "databasePreferences": NotRequired["DatabasePreferencesTypeDef"],
-        "prioritizeBusinessGoals": NotRequired["PrioritizeBusinessGoalsTypeDef"],
+        "applicationPreferences": "ApplicationPreferencesTypeDef",
+        "databasePreferences": "DatabasePreferencesTypeDef",
+        "prioritizeBusinessGoals": "PrioritizeBusinessGoalsTypeDef",
     },
+    total=False,
 )
 
 RecommendationReportDetailsTypeDef = TypedDict(
     "RecommendationReportDetailsTypeDef",
     {
-        "completionTime": NotRequired[datetime],
-        "s3Bucket": NotRequired[str],
-        "s3Keys": NotRequired[List[str]],
-        "startTime": NotRequired[datetime],
-        "status": NotRequired[RecommendationReportStatusType],
-        "statusMessage": NotRequired[str],
+        "completionTime": datetime,
+        "s3Bucket": str,
+        "s3Keys": List[str],
+        "startTime": datetime,
+        "status": RecommendationReportStatusType,
+        "statusMessage": str,
     },
+    total=False,
 )
 
 RecommendationSetTypeDef = TypedDict(
     "RecommendationSetTypeDef",
     {
-        "strategy": NotRequired[StrategyType],
-        "targetDestination": NotRequired[TargetDestinationType],
-        "transformationTool": NotRequired["TransformationToolTypeDef"],
+        "strategy": StrategyType,
+        "targetDestination": TargetDestinationType,
+        "transformationTool": "TransformationToolTypeDef",
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -689,9 +747,10 @@ ResponseMetadataTypeDef = TypedDict(
 S3ObjectTypeDef = TypedDict(
     "S3ObjectTypeDef",
     {
-        "s3Bucket": NotRequired[str],
-        "s3key": NotRequired[str],
+        "s3Bucket": str,
+        "s3key": str,
     },
+    total=False,
 )
 
 SelfManageResourcesTypeDef = TypedDict(
@@ -704,64 +763,70 @@ SelfManageResourcesTypeDef = TypedDict(
 ServerDetailTypeDef = TypedDict(
     "ServerDetailTypeDef",
     {
-        "antipatternReportS3Object": NotRequired["S3ObjectTypeDef"],
-        "antipatternReportStatus": NotRequired[AntipatternReportStatusType],
-        "antipatternReportStatusMessage": NotRequired[str],
-        "applicationComponentStrategySummary": NotRequired[List["StrategySummaryTypeDef"]],
-        "dataCollectionStatus": NotRequired[RunTimeAssessmentStatusType],
-        "id": NotRequired[str],
-        "lastAnalyzedTimestamp": NotRequired[datetime],
-        "listAntipatternSeveritySummary": NotRequired[List["AntipatternSeveritySummaryTypeDef"]],
-        "name": NotRequired[str],
-        "recommendationSet": NotRequired["RecommendationSetTypeDef"],
-        "serverType": NotRequired[str],
-        "statusMessage": NotRequired[str],
-        "systemInfo": NotRequired["SystemInfoTypeDef"],
+        "antipatternReportS3Object": "S3ObjectTypeDef",
+        "antipatternReportStatus": AntipatternReportStatusType,
+        "antipatternReportStatusMessage": str,
+        "applicationComponentStrategySummary": List["StrategySummaryTypeDef"],
+        "dataCollectionStatus": RunTimeAssessmentStatusType,
+        "id": str,
+        "lastAnalyzedTimestamp": datetime,
+        "listAntipatternSeveritySummary": List["AntipatternSeveritySummaryTypeDef"],
+        "name": str,
+        "recommendationSet": "RecommendationSetTypeDef",
+        "serverType": str,
+        "statusMessage": str,
+        "systemInfo": "SystemInfoTypeDef",
     },
+    total=False,
 )
 
 ServerStrategyTypeDef = TypedDict(
     "ServerStrategyTypeDef",
     {
-        "isPreferred": NotRequired[bool],
-        "numberOfApplicationComponents": NotRequired[int],
-        "recommendation": NotRequired["RecommendationSetTypeDef"],
-        "status": NotRequired[StrategyRecommendationType],
+        "isPreferred": bool,
+        "numberOfApplicationComponents": int,
+        "recommendation": "RecommendationSetTypeDef",
+        "status": StrategyRecommendationType,
     },
+    total=False,
 )
 
 ServerSummaryTypeDef = TypedDict(
     "ServerSummaryTypeDef",
     {
-        "ServerOsType": NotRequired[ServerOsTypeType],
-        "count": NotRequired[int],
+        "ServerOsType": ServerOsTypeType,
+        "count": int,
     },
+    total=False,
 )
 
 SourceCodeRepositoryTypeDef = TypedDict(
     "SourceCodeRepositoryTypeDef",
     {
-        "branch": NotRequired[str],
-        "repository": NotRequired[str],
-        "versionControlType": NotRequired[str],
+        "branch": str,
+        "repository": str,
+        "versionControlType": str,
     },
+    total=False,
 )
 
 SourceCodeTypeDef = TypedDict(
     "SourceCodeTypeDef",
     {
-        "location": NotRequired[str],
-        "sourceVersion": NotRequired[str],
-        "versionControl": NotRequired[VersionControlType],
+        "location": str,
+        "sourceVersion": str,
+        "versionControl": VersionControlType,
     },
+    total=False,
 )
 
 StartAssessmentRequestRequestTypeDef = TypedDict(
     "StartAssessmentRequestRequestTypeDef",
     {
-        "s3bucketForAnalysisData": NotRequired[str],
-        "s3bucketForReportData": NotRequired[str],
+        "s3bucketForAnalysisData": str,
+        "s3bucketForReportData": str,
     },
+    total=False,
 )
 
 StartAssessmentResponseTypeDef = TypedDict(
@@ -772,17 +837,31 @@ StartAssessmentResponseTypeDef = TypedDict(
     },
 )
 
-StartImportFileTaskRequestRequestTypeDef = TypedDict(
-    "StartImportFileTaskRequestRequestTypeDef",
+_RequiredStartImportFileTaskRequestRequestTypeDef = TypedDict(
+    "_RequiredStartImportFileTaskRequestRequestTypeDef",
     {
         "S3Bucket": str,
         "name": str,
         "s3key": str,
-        "dataSourceType": NotRequired[DataSourceTypeType],
-        "groupId": NotRequired[Sequence["GroupTypeDef"]],
-        "s3bucketForReportData": NotRequired[str],
     },
 )
+_OptionalStartImportFileTaskRequestRequestTypeDef = TypedDict(
+    "_OptionalStartImportFileTaskRequestRequestTypeDef",
+    {
+        "dataSourceType": DataSourceTypeType,
+        "groupId": Sequence["GroupTypeDef"],
+        "s3bucketForReportData": str,
+    },
+    total=False,
+)
+
+
+class StartImportFileTaskRequestRequestTypeDef(
+    _RequiredStartImportFileTaskRequestRequestTypeDef,
+    _OptionalStartImportFileTaskRequestRequestTypeDef,
+):
+    pass
+
 
 StartImportFileTaskResponseTypeDef = TypedDict(
     "StartImportFileTaskResponseTypeDef",
@@ -795,9 +874,10 @@ StartImportFileTaskResponseTypeDef = TypedDict(
 StartRecommendationReportGenerationRequestRequestTypeDef = TypedDict(
     "StartRecommendationReportGenerationRequestRequestTypeDef",
     {
-        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
-        "outputFormat": NotRequired[OutputFormatType],
+        "groupIdFilter": Sequence["GroupTypeDef"],
+        "outputFormat": OutputFormatType,
     },
+    total=False,
 )
 
 StartRecommendationReportGenerationResponseTypeDef = TypedDict(
@@ -818,55 +898,86 @@ StopAssessmentRequestRequestTypeDef = TypedDict(
 StrategyOptionTypeDef = TypedDict(
     "StrategyOptionTypeDef",
     {
-        "isPreferred": NotRequired[bool],
-        "strategy": NotRequired[StrategyType],
-        "targetDestination": NotRequired[TargetDestinationType],
-        "toolName": NotRequired[TransformationToolNameType],
+        "isPreferred": bool,
+        "strategy": StrategyType,
+        "targetDestination": TargetDestinationType,
+        "toolName": TransformationToolNameType,
     },
+    total=False,
 )
 
 StrategySummaryTypeDef = TypedDict(
     "StrategySummaryTypeDef",
     {
-        "count": NotRequired[int],
-        "strategy": NotRequired[StrategyType],
+        "count": int,
+        "strategy": StrategyType,
     },
+    total=False,
 )
 
 SystemInfoTypeDef = TypedDict(
     "SystemInfoTypeDef",
     {
-        "cpuArchitecture": NotRequired[str],
-        "fileSystemType": NotRequired[str],
-        "networkInfoList": NotRequired[List["NetworkInfoTypeDef"]],
-        "osInfo": NotRequired["OSInfoTypeDef"],
+        "cpuArchitecture": str,
+        "fileSystemType": str,
+        "networkInfoList": List["NetworkInfoTypeDef"],
+        "osInfo": "OSInfoTypeDef",
     },
+    total=False,
 )
 
 TransformationToolTypeDef = TypedDict(
     "TransformationToolTypeDef",
     {
-        "description": NotRequired[str],
-        "name": NotRequired[TransformationToolNameType],
-        "tranformationToolInstallationLink": NotRequired[str],
+        "description": str,
+        "name": TransformationToolNameType,
+        "tranformationToolInstallationLink": str,
     },
+    total=False,
 )
 
-UpdateApplicationComponentConfigRequestRequestTypeDef = TypedDict(
-    "UpdateApplicationComponentConfigRequestRequestTypeDef",
+_RequiredUpdateApplicationComponentConfigRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateApplicationComponentConfigRequestRequestTypeDef",
     {
         "applicationComponentId": str,
-        "inclusionStatus": NotRequired[InclusionStatusType],
-        "secretsManagerKey": NotRequired[str],
-        "sourceCodeList": NotRequired[Sequence["SourceCodeTypeDef"]],
-        "strategyOption": NotRequired["StrategyOptionTypeDef"],
     },
 )
+_OptionalUpdateApplicationComponentConfigRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateApplicationComponentConfigRequestRequestTypeDef",
+    {
+        "inclusionStatus": InclusionStatusType,
+        "secretsManagerKey": str,
+        "sourceCodeList": Sequence["SourceCodeTypeDef"],
+        "strategyOption": "StrategyOptionTypeDef",
+    },
+    total=False,
+)
 
-UpdateServerConfigRequestRequestTypeDef = TypedDict(
-    "UpdateServerConfigRequestRequestTypeDef",
+
+class UpdateApplicationComponentConfigRequestRequestTypeDef(
+    _RequiredUpdateApplicationComponentConfigRequestRequestTypeDef,
+    _OptionalUpdateApplicationComponentConfigRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredUpdateServerConfigRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateServerConfigRequestRequestTypeDef",
     {
         "serverId": str,
-        "strategyOption": NotRequired["StrategyOptionTypeDef"],
     },
 )
+_OptionalUpdateServerConfigRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateServerConfigRequestRequestTypeDef",
+    {
+        "strategyOption": "StrategyOptionTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateServerConfigRequestRequestTypeDef(
+    _RequiredUpdateServerConfigRequestRequestTypeDef,
+    _OptionalUpdateServerConfigRequestRequestTypeDef,
+):
+    pass
